**mLab Doppler Radar Tool: UART serial & data plot**

[![Latest PyPI version](https://img.shields.io/badge/pypi-v0.1-green.svg)](https://pypi.org/project/qt-ledwidget/)
[![License: MIT](https://img.shields.io/dub/l/vibe-d.svg)](https://opensource.org/licenses/MIT)

for Raspberry Pi,please install pyqt5-dev-tools, pyqt5-dev first. 